<?php

class Vote {

	public function voteProcess($userid,$userip,$votesiteid) {
		global $common;
		if(check_value($userid) && check_value($userip) && check_value($votesiteid)) {
			if(!Validator::Number($votesiteid)) { $error = true; }
			if(!Validator::Number($userid)) { $error = true; }
			if(!Validator::Ip($userip)) { $error = true; }
			if(!$error) {
				if($this->siteExists($votesiteid)) {
					if($this->canUserVote($userid,$votesiteid)) {
						if($this->canIPVote($userip,$votesiteid)) {
						
							// Retrieve Account Information
							$accountInfo = $common->accountInformation($userid);
							
							// Check Online Status
							if(mconfig('check_online')) {
								if($common->accountOnline($accountInfo['memb___id'])) {
									message('error', lang('error_14',true));
									return;
								}
							}
							
							// Retrieve votesite data
							$voteSite = $this->retrieveVotesites($votesiteid);
							if(!is_array($voteSite)) {
								message('error', lang('error_23',true));
								return;
							}
							
							$voteLink = $voteSite['votesite_link'];
							$creditsReward = $voteSite['votesite_reward'];
							
							// Give Reward
							$reward = $this->rewardUser($userid,$accountInfo['memb___id'],$creditsReward);
							
							if($reward) {
								// Add Vote Record
								$add = $this->addRecord($userid,$userip,$votesiteid);
								
								if($add) {
									// Log Vote
									if(mconfig('vote_save_logs')) {
										$this->logVote($votesiteid,$userid);
									}
									// Redirect
									redirect(3, $voteLink);
								} else {
									// unknown error
									message('error', lang('error_23',true));
								}
							} else {
								// unknown error
								message('error', lang('error_23',true));
							}
							
						} else {
							// ip already voted
							message('error', lang('error_16',true));
						}
					} else {
						// user id already voted
						message('error', lang('error_15',true));
					}
				} else {
					// vote site doesnt exist
					message('error', lang('error_23',true));
				}
			} else {
				// unknown error
				message('error', lang('error_23',true));
			}
		} else {
			// unknown error
			message('error', lang('error_23',true));
		}
	}

	private function canUserVote($userid,$votesiteid) {
		global $dB;
		$check = $dB->query_fetch_single("SELECT * FROM "._TBL_VOTES_." WHERE user_id = '$userid' AND vote_site_id = '$votesiteid'");
		if(is_array($check)) {
			if($this->timePassed($check['timestamp'])) {
				$remove = $this->removeRecord($check['id']);
				if($remove) {
					return true;
				}
			}
		} else {
			return true;
		}
	}
	
	private function canIPVote($ip,$votesiteid) {
		global $dB;
		$check = $dB->query_fetch_single("SELECT * FROM "._TBL_VOTES_." WHERE user_ip = '$ip' AND vote_site_id = '$votesiteid'");
		if(is_array($check)) {
			if($this->timePassed($check['timestamp'])) {
				$remove = $this->removeRecord($check['id']);
				if($remove) {
					return true;
				}
			}
		} else {
			return true;
		}
	}
	
	private function addRecord($userid,$userip,$votesiteid) {
		global $dB,$common;
		if(is_array($common->accountInformation($userid))) {
			if($this->siteExists($votesiteid)) {
				$voteSiteInfo = $this->retrieveVotesites($votesiteid);
				$timestamp = time() + $voteSiteInfo['votesite_time']*60*60;
				$data = array(
					$userid,
					$userip,
					$votesiteid,
					$timestamp
				);
				$add = $dB->query("INSERT INTO "._TBL_VOTES_." (user_id, user_ip, vote_site_id, timestamp) VALUES (?, ?, ?, ?)", $data);
				
				if($add) {
					return true;
				}
			}
		}
	}
	
	function removeRecord($id) {
		global $dB;
		$dB->query("DELETE FROM "._TBL_VOTES_." WHERE id = '$id'");
		return true;
	}
	
	function timePassed($timestamp) {
		if(time() > $timestamp) {
			return true;
		}
	}
	
	private function siteExists($id) {
		global $dB;
		if(check_value($id)) {
			$check = $dB->query_fetch_single("SELECT * FROM WEBENGINE_VOTE_SITES WHERE votesite_id = ?", array($id));
			if($check && is_array($check)) {
				return true;
			}
		}
	}
	
	function logVote($site_id,$user_id) {
		global $dB;
		$add_data = array(
			$user_id,
			$site_id,
			time()
		);
		$add_log = $dB->query("INSERT INTO "._TBL_VOTE_LOGS_." (user_id,votesite_id,timestamp) VALUES (?,?,?)", $add_data);
		if($add_log) {
			return true;
		}
	}
	
	private function buildQuery() {
		$table = (check_value(mconfig('credits_table')) ? mconfig('credits_table') : 'MEMB_INFO');
		$column = (check_value(mconfig('credits_column')) ? mconfig('credits_column') : 'TempCredits');
		$usercolumn = (check_value(mconfig('user_identifier_column')) ? mconfig('user_identifier_column') : 'memb___id');
		$result = "UPDATE $table SET $column = $column + ? WHERE $usercolumn = ?";
		return $result;
	}
	
	private function rewardUser($userid,$username,$credits) {
		global $dB,$dB2;
		$useriden = (mconfig('userid_or_username') == 1 ? $userid : $username);
		$query = $this->buildQuery();
		
		if(mconfig('credits_database') == 1) {
			$result = $dB->query($query, array($credits, $useriden));
		} else {
			$result = $dB2->query($query, array($credits, $useriden));
		}
		
		if($result) {
			return true;
		}
	}
	
	public function addVotesite($title,$link,$reward,$time) {
		global $dB;
		$result = $dB->query("INSERT INTO WEBENGINE_VOTE_SITES (votesite_title,votesite_link,votesite_reward,votesite_time) VALUES (?,?,?,?)", array($title,$link,$reward,$time));
		if($result) {
			return true;
		}
	}
	
	public function deleteVotesite($id) {
		global $dB;
		if($this->siteExists($id)) {
			$result = $dB->query("DELETE FROM WEBENGINE_VOTE_SITES WHERE votesite_id = ?", array($id));
			if($result) {
				return $result;
			}
		}
	}
	
	public function retrieveVotesites($id=null) {
		global $dB;
		if(check_value($id)) {
			return $dB->query_fetch_single("SELECT * FROM WEBENGINE_VOTE_SITES WHERE votesite_id = ?", array($id));
		} else {
			return $dB->query_fetch("SELECT * FROM WEBENGINE_VOTE_SITES ORDER BY votesite_id ASC");
		}
	}

}

?>